==> spip_4.0.4.orig.tar.xz: plugins-dist/dump/lang/dump_oc_gsc.php <==
<?php
// This is a SPIP language file  --  Ceci est un fichier langue de SPIP
// extrait automatiquement de https://trad.spip.net/tradlang_module/dump?lang_cible=oc_gsc
// ** ne pas modifier le fichier **

if (!defined('_ECRIRE_INC_VERSION')) {
	return;
}

$GLOBALS[$GLOBALS['idx_lang']] = array(

	// B
	'bouton_restaurer_base' => 'Restaurar la basa',

	// I
	'info_restauration_sauvegarde' => 'restauracion de la sauvagarda @archive@', # MODIF
	'info_sauvegarde' => 'Sauvagarda',
	'info_sauvegarde_reussi_02' => 'La basa qu’ei estada sauvagardada dens @archive@. Que podetz',
	'info_sauvegarde_reussi_03' => 'tornar a la gestion',
	'info_sauvegarde_reussi_04' => 'deu vòste sit.',

	// T
	'texte_admin_tech_01' => 'Aquera opcion que’vs permet de sauvagardar lo contengut de la basa dens un fichièr qui serà servat dens lo repertòri @dossier@.
N’oblidetz pas tanpòc de recuperar l’integralitat deu repertòri <i>IMG/</i>, qui contien los imatges e los documents utilizats dens los articles e rubricas.',
	'texte_admin_tech_02' => 'Atencion: aquera sauvagarda que’s poirà restaurar SONQUE dens un sit installat dab la medisha version d’SPIP. Donc subertot non cau pas "vueidar la basa" en esperar de reïnstallar la sauvagarda après ua actualizacion. Consultatz <a href="@spipnet@">la documentacion d’SPIP</a>.', # MODIF
	'texte_restaurer_base' => 'Restaurar lo contengut d’ua sauvagarda de la basa',
	'texte_restaurer_sauvegarde' => 'Aquera opcion que’vs permet de restaurar ua sauvagarda 
 de la basa que l’avèvatz hèita abans. Tà har aquò, que cau aver botat lo fichièr qui contien la sauvagarda 
dens lo repertòri @dossier@.
  Totun, siatz prudent(a) dab aquera foncionalitat: <b>las modificacions e pèrdas eventuaus que son
  irreversiblas.</b>', # MODIF
	'texte_sauvegarde' => 'Sauvagardar lo contengut de la basa',
	'texte_sauvegarde_base' => 'Sauvagardar la basa'
);

==> spip_4.4.6+dfsg.orig.tar.xz: plugins-dist/dump/lang/dump_oc_gsc.php <==
<?php
// This is a SPIP language file  --  Ceci est un fichier langue de SPIP
// extrait automatiquement de https://trad.spip.net/tradlang_module/dump?lang_cible=oc_gsc
// ** ne pas modifier le fichier **

return [

	// B
	'bouton_restaurer_base' => 'Restaurar la basa',

	// I
	'info_restauration_sauvegarde' => 'restauracion de la sauvagarda @archive@', # MODIF
	'info_sauvegarde' => 'Sauvagarda',
	'info_sauvegarde_reussi_02' => 'La basa qu’ei estada sauvagardada dens @archive@. Que podetz',
	'info_sauvegarde_reussi_03' => 'tornar a la gestion',
	'info_sauvegarde_reussi_04' => 'deu vòste sit.',

	// T
	'texte_admin_tech_01' => 'Aquera opcion que’vs permet de sauvagardar lo contengut de la basa dens un fichièr qui serà servat dens lo repertòri @dossier@.
N’oblidetz pas tanpòc de recuperar l’integralitat deu repertòri <i>IMG/</i>, qui contien los imatges e los documents utilizats dens los articles e rubricas.',
	'texte_admin_tech_02' => 'Atencion: aquera sauvagarda que’s poirà restaurar SONQUE dens un sit installat dab la medisha version d’SPIP. Donc subertot non cau pas "vueidar la basa" en esperar de reïnstallar la sauvagarda après ua actualizacion. Consultatz <a href="@spipnet@">la documentacion d’SPIP</a>.', # MODIF
	'texte_restaurer_base' => 'Restaurar lo contengut d’ua sauvagarda de la basa',
	'texte_restaurer_sauvegarde' => 'Aquera opcion que’vs permet de restaurar ua sauvagarda 
 de la basa que l’avèvatz hèita abans. Tà har aquò, que cau aver botat lo fichièr qui contien la sauvagarda 
dens lo repertòri @dossier@.
  Totun, siatz prudent(a) dab aquera foncionalitat: <b>las modificacions e pèrdas eventuaus que son
  irreversiblas.</b>', # MODIF
	'texte_sauvegarde' => 'Sauvagardar lo contengut de la basa',
	'texte_sauvegarde_base' => 'Sauvagardar la basa',
];
